@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 # import params is just one 'no-unicode-escape-permanently'
 # if set, then unicode escaping will not happen at
@@ -205,6 +205,10 @@ sub	yaml2perl {
 	my $yaml_string = $_[0];
 	#my $params = defined($_[1]) ? $_[1] : {};
 	# intercepting a die by wrapping in an eval
+	# Untainting YAML::PP string input because of a bug that causes it to bomb
+	# see https://perlmonks.org/?node_id=11154911
+	# untaint recipe by ysth, see https://www.perlmonks.org/?node_id=516862
+	($yaml_string) = each %{{$yaml_string,0}};
 	my $pv = eval { YAML::PP::Load($yaml_string) };
 	if( $@ || ! defined($pv) ){ warn "yaml2perl() : error, call to YAML::PP::Load() has failed".(defined($@)?" with this exception:\n".$@:"")."."; return undef }
 	return $pv
@@ -630,7 +634,7 @@ Data::Roundtrip - convert between Perl data structures, YAML and JSON with unico
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =head1 SYNOPSIS
 
